using System.ComponentModel.Composition;
using Jounce.Core.Command;
using Jounce.Core.Event;
using Jounce.Core.View;
using Jounce.Core.ViewModel;
using Jounce.Framework;
using Jounce.Framework.Command;

namespace EvenSimplerNavigation.ViewModel
{
    /// <summary>
    ///     This ViewModel is both publishing and consuming the ViewNavigationArgs for purposes of demo
    /// </summary>
    [ExportAsViewModel("MainViewModel")]
    public class MainViewModel: BaseViewModel, IPartImportsSatisfiedNotification, IEventSink<ViewNavigationArgs>
    {
        public IActionCommand<string> NavigateCommand { get; private set; }

        private object _currentView;
        public object CurrentView
        {
            get { return _currentView; }
            set
            {
                _currentView = value;
                RaisePropertyChanged(() => CurrentView);
                NavigateCommand.RaiseCanExecuteChanged();
            }
        }

        #region IEventSink<ViewNavigationArgs> Members

        public void HandleEvent(ViewNavigationArgs publishedEvent)
        {
            CurrentView = Router[publishedEvent.ViewType];
        }

        #endregion

        #region IPartImportsSatisfiedNotification Members

        public void OnImportsSatisfied()
        {
            NavigateCommand = new ActionCommand<string>(
                view =>
                {
                    CurrentView = view;
                    EventAggregator.Publish(view.AsViewNavigationArgs());
                },
                view => true);

            EventAggregator.SubscribeOnDispatcher(this);
        }

        #endregion
    }
}